@@ -15,9 +15,11 @@ from paxd.app.command import Command, init_process
 class Application(object):
     DEFAULT_WORKERS = 2
     
-    def __init__(self, name, data_root, env, packages, 
+    def __init__(self, broker_host, broker_port, name, data_root, env, packages, 
                     commands, num_workers, version, 
                     python_paths, group, system, state='stopped'):
+        self.broker_host = broker_host
+        self.broker_port = broker_port
         self.lock = RLock()
         self.data_root = data_root
         self.env = env
@@ -107,7 +109,7 @@ class Application(object):
         return (kwargs['name'], kwargs['group'], kwargs['version'])
     
     @classmethod
-    def from_conf(cls, path, conf, instance_id, system=False, group=None):
+    def from_conf(cls, broker_host, broker_port, path, conf, instance_id, system=False, group=None):
         app_args = {
             'name' : conf['name'],
             'group' : conf.get('group', 'default'),
@@ -128,11 +130,11 @@ class Application(object):
         
         app_args['commands'] = {}
         for queue, c in conf.get('commands', {}).iteritems():
-            com = Command.from_conf(queue, c, path, app_args['python_paths'], app_args['env'], instance_id, 
+            com = Command.from_conf(broker_host, broker_port, queue, c, path, app_args['python_paths'], app_args['env'], instance_id, 
                     shared_size=app_args['num_workers'], version=app_args['version'])
             app_args['commands'][queue] = com
         
-        return Application(**app_args)
+        return Application(broker_host, broker_port, **app_args)
     
     def update(self, path, conf, instance_id):
         '''
@@ -153,7 +155,7 @@ class Application(object):
         
         self.commands = {}
         for queue, c in conf.get('commands', {}).iteritems():
-            com = Command.from_conf(queue, c, self.data_root, self.python_paths, self.env, instance_id, 
+            com = Command.from_conf(broker_host, broker_port, queue, c, self.data_root, self.python_paths, self.env, instance_id, 
                     shared_size=self.DEFAULT_WORKERS, version=self.version)
             self.commands[queue] = com
         for q, c in old_commands.iteritems():
