@@ -45,14 +45,16 @@ def init_process(paths, env):
         os.environ[k] = v
 
 class Command(object):
-    def __init__(self, queue, entry, base_path, python_paths, environment, instance_id, shared_size, state='stopped', num_processes=max(cpu_count(), 2), version=''):
+    def __init__(self, broker_host, broker_port, queue, entry, base_path, python_paths, environment, instance_id, shared_size, state='stopped', num_processes=max(cpu_count(), 2), version=''):
+        self.broker_host = broker_host
+        self.broker_port = broker_port
         self.entry = entry
         self.queue = queue
         self.base_path = base_path
         self.python_paths = python_paths
         self.environment = environment
         self.instance_id = instance_id
-        self.redis = Redis('localhost')
+        self.redis = Redis(broker_host, port=broker_port)
         self.lock = RLock()
         
         # computed fields
@@ -155,7 +157,7 @@ class Command(object):
 
     
     @classmethod
-    def from_conf(self, queue, data, base_path, paths, environment, instance_id, shared_size, version):
+    def from_conf(self, broker_host, broker_port, queue, data, base_path, paths, environment, instance_id, shared_size, version):
         c_args = {
             'entry' : data.get('entry', queue),
             'queue' : queue,
@@ -171,7 +173,7 @@ class Command(object):
         
         if 'processes' in data:
             c_args['num_processes'] = data['processes']
-        return Command(**c_args)
+        return Command(broker_host, broker_port, **c_args)
     
     @property
     def trace(self):
@@ -225,7 +227,7 @@ class TaskQueue(Thread):
     def __init__(self, command):
         Thread.__init__(self)
         self.command = command
-        self.redis = Redis('localhost')
+        self.redis = Redis(command.broker_host, port=command.broker_port)
         self.queue = Queue()
     
     def get(self, timeout=None):
@@ -268,7 +270,7 @@ class ResultWriter(Thread):
         self.command = command
         self.lock = RLock()
         self.pending = []
-        self.redis = Redis('localhost')
+        self.redis = Redis(command.broker_host, port=command.broker_port)
     
     def add_pending(self, result):
         with self.lock:
