@@ -10,15 +10,17 @@ import uuid
 from signal import signal, SIGINT
 from paxd.app.msg import PRequest #, BaseResponse
 
-def start_webui(name):
-    WebUI(name).start()
+def start_webui(broker_host, broker_port, name):
+    WebUI(name, broker_host, broker_port).start()
     
 class WebUI(object):
-    def __init__(self, name):
+    def __init__(self, name, broker_host, broker_port):
         self.name = name
+        self.broker_host = broker_host
+        self.broker_port = broker_port
     
     def start(self):
-        http_server = Thread(target=start_server, args=(self.name,))
+        http_server = Thread(target=start_server, args=(self.broker_host, self.broker_port, self.name))
         http_server.daemon = True
         http_server.start()
         # signal(SIGINT, sigint_handler)
@@ -33,8 +35,8 @@ from BaseHTTPServer import HTTPServer, BaseHTTPRequestHandler
 
 shut_down = None
 
-def start_server(name):
-    redis = Redis('localhost')
+def start_server(broker_host, broker_port, name):
+    redis = Redis(broker_host, port=broker_port)
     print 'SENDING REQUESTS TO', name
     class WebUIHandler(BaseHTTPRequestHandler):
         def do_GET(self):
